
#ifndef _C13_re644_
#define _C13_re644_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F567_2699(EIF_REFERENCE);
extern void EIF_Minit644(void);
extern EIF_INTEGER_32 F642_3165(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
